==> maven-surefire-3.2.5.tar.xz: maven-surefire-3.2.5/surefire-its/src/test/java/org/apache/maven/surefire/its/PojoSimpleIT.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.maven.surefire.its;

import org.apache.maven.it.VerificationException;
import org.apache.maven.surefire.its.fixture.SurefireJUnit4IntegrationTestCase;
import org.junit.Test;

import static org.hamcrest.Matchers.containsString;
import static org.hamcrest.Matchers.is;

/**
 * Test support for POJO tests.
 *
 * @author Benjamin Bentmann
 */
public class PojoSimpleIT extends SurefireJUnit4IntegrationTestCase {
    @Test
    public void twoTestsWithFixtures() throws VerificationException {
        unpack("pojo-simple")
                .executeTest()
                .assertTestSuiteResults(2, 0, 1, 0)
                .assertThatLogLine(containsString("setUp called 1"), is(1))
                .assertThatLogLine(containsString("setUp called 2"), is(1))
                .assertThatLogLine(containsString("tearDown called 1"), is(1))
                .assertThatLogLine(containsString("tearDown called 2"), is(1));
    }
}

==> maven-surefire-3.5.2.tar.xz: maven-surefire-3.5.2/surefire-its/src/test/java/org/apache/maven/surefire/its/PojoSimpleIT.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.maven.surefire.its;

import org.apache.maven.shared.verifier.VerificationException;
import org.apache.maven.surefire.its.fixture.SurefireJUnit4IntegrationTestCase;
import org.junit.Test;

import static org.hamcrest.Matchers.containsString;
import static org.hamcrest.Matchers.is;

/**
 * Test support for POJO tests.
 *
 * @author Benjamin Bentmann
 */
public class PojoSimpleIT extends SurefireJUnit4IntegrationTestCase {
    @Test
    public void twoTestsWithFixtures() throws VerificationException {
        unpack("pojo-simple")
                .executeTest()
                .assertTestSuiteResults(2, 0, 1, 0)
                .assertThatLogLine(containsString("setUp called 1"), is(1))
                .assertThatLogLine(containsString("setUp called 2"), is(1))
                .assertThatLogLine(containsString("tearDown called 1"), is(1))
                .assertThatLogLine(containsString("tearDown called 2"), is(1));
    }
}
